@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,17 +16,20 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.cloud.secretmanager_v1.services.secret_manager_service import pagers
 from google.cloud.secretmanager_v1.types import resources
@@ -122,6 +125,42 @@ class SecretManagerServiceAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return SecretManagerServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> SecretManagerServiceTransport:
         """Returns the transport used by the client instance.
@@ -194,6 +233,26 @@ class SecretManagerServiceAsyncClient:
     ) -> pagers.ListSecretsAsyncPager:
         r"""Lists [Secrets][google.cloud.secretmanager.v1.Secret].
 
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_list_secrets():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.ListSecretsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_secrets(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.ListSecretsRequest, dict]):
                 The request object. Request message for
@@ -223,7 +282,7 @@ class SecretManagerServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -280,6 +339,27 @@ class SecretManagerServiceAsyncClient:
         containing no
         [SecretVersions][google.cloud.secretmanager.v1.SecretVersion].
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_create_secret():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.CreateSecretRequest(
+                    parent="parent_value",
+                    secret_id="secret_id_value",
+                )
+
+                # Make the request
+                response = client.create_secret(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.CreateSecretRequest, dict]):
                 The request object. Request message for
@@ -329,7 +409,7 @@ class SecretManagerServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, secret_id, secret])
         if request is not None and has_flattened_params:
@@ -384,6 +464,26 @@ class SecretManagerServiceAsyncClient:
         containing secret data and attaches it to an existing
         [Secret][google.cloud.secretmanager.v1.Secret].
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_add_secret_version():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.AddSecretVersionRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.add_secret_version(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.AddSecretVersionRequest, dict]):
                 The request object. Request message for
@@ -418,7 +518,7 @@ class SecretManagerServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, payload])
         if request is not None and has_flattened_params:
@@ -468,6 +568,26 @@ class SecretManagerServiceAsyncClient:
         r"""Gets metadata for a given
         [Secret][google.cloud.secretmanager.v1.Secret].
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_get_secret():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.GetSecretRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_secret(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.GetSecretRequest, dict]):
                 The request object. Request message for
@@ -498,7 +618,7 @@ class SecretManagerServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -547,6 +667,25 @@ class SecretManagerServiceAsyncClient:
         r"""Updates metadata of an existing
         [Secret][google.cloud.secretmanager.v1.Secret].
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_update_secret():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.UpdateSecretRequest(
+                )
+
+                # Make the request
+                response = client.update_secret(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.UpdateSecretRequest, dict]):
                 The request object. Request message for
@@ -583,7 +722,7 @@ class SecretManagerServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([secret, update_mask])
         if request is not None and has_flattened_params:
@@ -634,6 +773,22 @@ class SecretManagerServiceAsyncClient:
     ) -> None:
         r"""Deletes a [Secret][google.cloud.secretmanager.v1.Secret].
 
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_delete_secret():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.DeleteSecretRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_secret(request=request)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.DeleteSecretRequest, dict]):
                 The request object. Request message for
@@ -653,7 +808,7 @@ class SecretManagerServiceAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -701,6 +856,27 @@ class SecretManagerServiceAsyncClient:
         [SecretVersions][google.cloud.secretmanager.v1.SecretVersion].
         This call does not return secret data.
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_list_secret_versions():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.ListSecretVersionsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_secret_versions(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.ListSecretVersionsRequest, dict]):
                 The request object. Request message for
@@ -731,7 +907,7 @@ class SecretManagerServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -789,6 +965,26 @@ class SecretManagerServiceAsyncClient:
         recently created
         [SecretVersion][google.cloud.secretmanager.v1.SecretVersion].
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_get_secret_version():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.GetSecretVersionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_secret_version(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.GetSecretVersionRequest, dict]):
                 The request object. Request message for
@@ -818,7 +1014,7 @@ class SecretManagerServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -871,6 +1067,26 @@ class SecretManagerServiceAsyncClient:
         recently created
         [SecretVersion][google.cloud.secretmanager.v1.SecretVersion].
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_access_secret_version():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.AccessSecretVersionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.access_secret_version(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.AccessSecretVersionRequest, dict]):
                 The request object. Request message for
@@ -900,7 +1116,7 @@ class SecretManagerServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -964,6 +1180,26 @@ class SecretManagerServiceAsyncClient:
         to
         [DISABLED][google.cloud.secretmanager.v1.SecretVersion.State.DISABLED].
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_disable_secret_version():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.DisableSecretVersionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.disable_secret_version(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.DisableSecretVersionRequest, dict]):
                 The request object. Request message for
@@ -990,7 +1226,7 @@ class SecretManagerServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1044,6 +1280,26 @@ class SecretManagerServiceAsyncClient:
         to
         [ENABLED][google.cloud.secretmanager.v1.SecretVersion.State.ENABLED].
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_enable_secret_version():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.EnableSecretVersionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.enable_secret_version(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.EnableSecretVersionRequest, dict]):
                 The request object. Request message for
@@ -1070,7 +1326,7 @@ class SecretManagerServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1125,6 +1381,26 @@ class SecretManagerServiceAsyncClient:
         [DESTROYED][google.cloud.secretmanager.v1.SecretVersion.State.DESTROYED]
         and irrevocably destroys the secret data.
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_destroy_secret_version():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.DestroySecretVersionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.destroy_secret_version(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.DestroySecretVersionRequest, dict]):
                 The request object. Request message for
@@ -1151,7 +1427,7 @@ class SecretManagerServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1203,6 +1479,26 @@ class SecretManagerServiceAsyncClient:
         are enforced according to the policy set on the associated
         [Secret][google.cloud.secretmanager.v1.Secret].
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_set_iam_policy():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.SetIamPolicyRequest(
+                    resource="resource_value",
+                )
+
+                # Make the request
+                response = client.set_iam_policy(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.iam.v1.iam_policy_pb2.SetIamPolicyRequest, dict]):
                 The request object. Request message for `SetIamPolicy`
@@ -1310,6 +1606,26 @@ class SecretManagerServiceAsyncClient:
         Returns empty policy if the secret exists and does not
         have a policy set.
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_get_iam_policy():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.GetIamPolicyRequest(
+                    resource="resource_value",
+                )
+
+                # Make the request
+                response = client.get_iam_policy(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.iam.v1.iam_policy_pb2.GetIamPolicyRequest, dict]):
                 The request object. Request message for `GetIamPolicy`
@@ -1422,6 +1738,27 @@ class SecretManagerServiceAsyncClient:
         authorization checking. This operation may "fail open" without
         warning.
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_test_iam_permissions():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.TestIamPermissionsRequest(
+                    resource="resource_value",
+                    permissions=['permissions_value_1', 'permissions_value_2'],
+                )
+
+                # Make the request
+                response = client.test_iam_permissions(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest, dict]):
                 The request object. Request message for
