@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,23 +14,25 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
 from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.cloud.secretmanager_v1.services.secret_manager_service import pagers
 from google.cloud.secretmanager_v1.types import resources
@@ -271,6 +273,73 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -321,50 +390,22 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, SecretManagerServiceTransport):
             # transport is a SecretManagerServiceTransport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -376,6 +417,15 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -399,6 +449,26 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
     ) -> pagers.ListSecretsPager:
         r"""Lists [Secrets][google.cloud.secretmanager.v1.Secret].
 
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_list_secrets():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.ListSecretsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_secrets(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.ListSecretsRequest, dict]):
                 The request object. Request message for
@@ -428,7 +498,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -485,6 +555,27 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         containing no
         [SecretVersions][google.cloud.secretmanager.v1.SecretVersion].
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_create_secret():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.CreateSecretRequest(
+                    parent="parent_value",
+                    secret_id="secret_id_value",
+                )
+
+                # Make the request
+                response = client.create_secret(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.CreateSecretRequest, dict]):
                 The request object. Request message for
@@ -534,7 +625,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, secret_id, secret])
         if request is not None and has_flattened_params:
@@ -589,6 +680,26 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         containing secret data and attaches it to an existing
         [Secret][google.cloud.secretmanager.v1.Secret].
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_add_secret_version():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.AddSecretVersionRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.add_secret_version(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.AddSecretVersionRequest, dict]):
                 The request object. Request message for
@@ -623,7 +734,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, payload])
         if request is not None and has_flattened_params:
@@ -673,6 +784,26 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         r"""Gets metadata for a given
         [Secret][google.cloud.secretmanager.v1.Secret].
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_get_secret():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.GetSecretRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_secret(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.GetSecretRequest, dict]):
                 The request object. Request message for
@@ -703,7 +834,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -752,6 +883,25 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         r"""Updates metadata of an existing
         [Secret][google.cloud.secretmanager.v1.Secret].
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_update_secret():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.UpdateSecretRequest(
+                )
+
+                # Make the request
+                response = client.update_secret(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.UpdateSecretRequest, dict]):
                 The request object. Request message for
@@ -788,7 +938,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([secret, update_mask])
         if request is not None and has_flattened_params:
@@ -839,6 +989,22 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
     ) -> None:
         r"""Deletes a [Secret][google.cloud.secretmanager.v1.Secret].
 
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_delete_secret():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.DeleteSecretRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_secret(request=request)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.DeleteSecretRequest, dict]):
                 The request object. Request message for
@@ -858,7 +1024,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -906,6 +1072,27 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         [SecretVersions][google.cloud.secretmanager.v1.SecretVersion].
         This call does not return secret data.
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_list_secret_versions():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.ListSecretVersionsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_secret_versions(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.ListSecretVersionsRequest, dict]):
                 The request object. Request message for
@@ -936,7 +1123,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -994,6 +1181,26 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         recently created
         [SecretVersion][google.cloud.secretmanager.v1.SecretVersion].
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_get_secret_version():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.GetSecretVersionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_secret_version(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.GetSecretVersionRequest, dict]):
                 The request object. Request message for
@@ -1023,7 +1230,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1076,6 +1283,26 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         recently created
         [SecretVersion][google.cloud.secretmanager.v1.SecretVersion].
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_access_secret_version():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.AccessSecretVersionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.access_secret_version(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.AccessSecretVersionRequest, dict]):
                 The request object. Request message for
@@ -1105,7 +1332,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1159,6 +1386,26 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         to
         [DISABLED][google.cloud.secretmanager.v1.SecretVersion.State.DISABLED].
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_disable_secret_version():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.DisableSecretVersionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.disable_secret_version(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.DisableSecretVersionRequest, dict]):
                 The request object. Request message for
@@ -1185,7 +1432,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1239,6 +1486,26 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         to
         [ENABLED][google.cloud.secretmanager.v1.SecretVersion.State.ENABLED].
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_enable_secret_version():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.EnableSecretVersionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.enable_secret_version(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.EnableSecretVersionRequest, dict]):
                 The request object. Request message for
@@ -1265,7 +1532,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1320,6 +1587,26 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         [DESTROYED][google.cloud.secretmanager.v1.SecretVersion.State.DESTROYED]
         and irrevocably destroys the secret data.
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_destroy_secret_version():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.DestroySecretVersionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.destroy_secret_version(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.secretmanager_v1.types.DestroySecretVersionRequest, dict]):
                 The request object. Request message for
@@ -1346,7 +1633,7 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1398,6 +1685,26 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         are enforced according to the policy set on the associated
         [Secret][google.cloud.secretmanager.v1.Secret].
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_set_iam_policy():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.SetIamPolicyRequest(
+                    resource="resource_value",
+                )
+
+                # Make the request
+                response = client.set_iam_policy(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.iam.v1.iam_policy_pb2.SetIamPolicyRequest, dict]):
                 The request object. Request message for `SetIamPolicy`
@@ -1504,6 +1811,26 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         Returns empty policy if the secret exists and does not
         have a policy set.
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_get_iam_policy():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.GetIamPolicyRequest(
+                    resource="resource_value",
+                )
+
+                # Make the request
+                response = client.get_iam_policy(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.iam.v1.iam_policy_pb2.GetIamPolicyRequest, dict]):
                 The request object. Request message for `GetIamPolicy`
@@ -1615,6 +1942,27 @@ class SecretManagerServiceClient(metaclass=SecretManagerServiceClientMeta):
         authorization checking. This operation may "fail open" without
         warning.
 
+
+        .. code-block:: python
+
+            from google.cloud import secretmanager_v1
+
+            def sample_test_iam_permissions():
+                # Create a client
+                client = secretmanager_v1.SecretManagerServiceClient()
+
+                # Initialize request argument(s)
+                request = secretmanager_v1.TestIamPermissionsRequest(
+                    resource="resource_value",
+                    permissions=['permissions_value_1', 'permissions_value_2'],
+                )
+
+                # Make the request
+                response = client.test_iam_permissions(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest, dict]):
                 The request object. Request message for
