@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -90,10 +90,12 @@ class Secret(proto.Message):
             [Secret][google.cloud.secretmanager.v1.Secret] is scheduled
             to expire. This is always provided on output, regardless of
             what was sent on input.
+
             This field is a member of `oneof`_ ``expiration``.
         ttl (google.protobuf.duration_pb2.Duration):
             Input only. The TTL for the
             [Secret][google.cloud.secretmanager.v1.Secret].
+
             This field is a member of `oneof`_ ``expiration``.
         etag (str):
             Optional. Etag of the currently stored
@@ -152,6 +154,13 @@ class SecretVersion(proto.Message):
         etag (str):
             Output only. Etag of the currently stored
             [SecretVersion][google.cloud.secretmanager.v1.SecretVersion].
+        client_specified_payload_checksum (bool):
+            Output only. True if payload checksum specified in
+            [SecretPayload][google.cloud.secretmanager.v1.SecretPayload]
+            object has been received by
+            [SecretManagerService][google.cloud.secretmanager.v1.SecretManagerService]
+            on
+            [SecretManagerService.AddSecretVersion][google.cloud.secretmanager.v1.SecretManagerService.AddSecretVersion].
     """
 
     class State(proto.Enum):
@@ -174,6 +183,7 @@ class SecretVersion(proto.Message):
         proto.MESSAGE, number=5, message="ReplicationStatus",
     )
     etag = proto.Field(proto.STRING, number=6,)
+    client_specified_payload_checksum = proto.Field(proto.BOOL, number=7,)
 
 
 class Replication(proto.Message):
@@ -191,10 +201,12 @@ class Replication(proto.Message):
         automatic (google.cloud.secretmanager_v1.types.Replication.Automatic):
             The [Secret][google.cloud.secretmanager.v1.Secret] will
             automatically be replicated without any restrictions.
+
             This field is a member of `oneof`_ ``replication``.
         user_managed (google.cloud.secretmanager_v1.types.Replication.UserManaged):
             The [Secret][google.cloud.secretmanager.v1.Secret] will only
             be replicated into the locations specified.
+
             This field is a member of `oneof`_ ``replication``.
     """
 
@@ -277,8 +289,8 @@ class Replication(proto.Message):
 
 
 class CustomerManagedEncryption(proto.Message):
-    r"""Configuration for encrypting secret payloads using customer-
-    anaged encryption keys (CMEK).
+    r"""Configuration for encrypting secret payloads using
+    customer-managed encryption keys (CMEK).
 
     Attributes:
         kms_key_name (str):
@@ -323,6 +335,7 @@ class ReplicationStatus(proto.Message):
             Only populated if the parent
             [Secret][google.cloud.secretmanager.v1.Secret] has an
             automatic replication policy.
+
             This field is a member of `oneof`_ ``replication_status``.
         user_managed (google.cloud.secretmanager_v1.types.ReplicationStatus.UserManagedStatus):
             Describes the replication status of a
@@ -332,6 +345,7 @@ class ReplicationStatus(proto.Message):
             Only populated if the parent
             [Secret][google.cloud.secretmanager.v1.Secret] has a
             user-managed replication policy.
+
             This field is a member of `oneof`_ ``replication_status``.
     """
 
@@ -484,9 +498,31 @@ class SecretPayload(proto.Message):
         data (bytes):
             The secret data. Must be no larger than
             64KiB.
+        data_crc32c (int):
+            Optional. If specified,
+            [SecretManagerService][google.cloud.secretmanager.v1.SecretManagerService]
+            will verify the integrity of the received
+            [data][google.cloud.secretmanager.v1.SecretPayload.data] on
+            [SecretManagerService.AddSecretVersion][google.cloud.secretmanager.v1.SecretManagerService.AddSecretVersion]
+            calls using the crc32c checksum and store it to include in
+            future
+            [SecretManagerService.AccessSecretVersion][google.cloud.secretmanager.v1.SecretManagerService.AccessSecretVersion]
+            responses. If a checksum is not provided in the
+            [SecretManagerService.AddSecretVersion][google.cloud.secretmanager.v1.SecretManagerService.AddSecretVersion]
+            request, the
+            [SecretManagerService][google.cloud.secretmanager.v1.SecretManagerService]
+            will generate and store one for you.
+
+            The CRC32C value is encoded as a Int64 for compatibility,
+            and can be safely downconverted to uint32 in languages that
+            support this type.
+            https://cloud.google.com/apis/design/design_patterns#integer_types
+
+            This field is a member of `oneof`_ ``_data_crc32c``.
     """
 
     data = proto.Field(proto.BYTES, number=1,)
+    data_crc32c = proto.Field(proto.INT64, number=2, optional=True,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
